Learn R Programming

RSuite (version 0.37-253)

tmpl_list_registered: Returns all available project/package templates

Description

Returns all available project/package templates

Usage

tmpl_list_registered()

Arguments

Value

names of the registered project and package templates together with their file path

Details

Project templates have to include a PARAMETERS file Package templates have to include the following files: DESCRIPTION

All templates can be found in folder pointed by rsuite.user_templ_path option.

See Also

Other in templates management: tmpl_start

Examples

Run this code
# NOT RUN {
tmpl_list_registered()

# }

Run the code above in your browser using DataLab