powered by
Returns all available project/package templates
tmpl_list_registered()
names of the registered project and package templates together with their file path
Project templates have to include a PARAMETERS file Package templates have to include the following files: DESCRIPTION
All templates can be found in folder pointed by rsuite.user_templ_path option.
Other in templates management: tmpl_start
tmpl_start
# NOT RUN { tmpl_list_registered() # }
Run the code above in your browser using DataLab